/***************************************************************************
 *            cashobjects.h
 *
 *  Fri Aug 19 21:43:02 2005
 *  Copyright  2005  Neil Williams
 *  linux@codehelp.co.uk
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 *  02110-1301, USA.
 */

/* a convenience header for anyone working with the libcashobjects.la library. */

#ifndef _CASHOBJECTS_H
#define _CASHOBJECTS_H

#include <glib.h>

#ifdef __cplusplus
extern "C" {
#endif

gboolean cashobjects_register(void);

#ifdef __cplusplus
}
#endif

#endif /* _CASHOBJECTS_H */
